@@ -1,21 +1,25 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Sequence
+from typing import Any, Dict, List, Optional, Sequence, TypedDict
 
 from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from .errors import ServerError
-from .retry import retry_policy
+from ..errors import ServerError
+from ..retry import retry_policy
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/alerts"
 
 Alert = Dict[str, Any]
-AlertsMeta = Dict[str, Any]
-AlertsResponse = Dict[str, Any]
+
+
+class AlertsResponse(TypedDict):
+    page: int
+    num_pages: int
+    alerts: List[Alert]
 
 
 class BaseAlertsResource(ABC):
@@ -51,7 +55,9 @@ class BaseAlertsResource(ABC):
             raise ServerError(response.text)
 
         assert response.status_code == 200, response.text
-        return response.json()  # type: ignore
+
+        alerts_response: AlertsResponse = response.json()
+        return alerts_response
 
     @validate_arguments
     @cache
@@ -72,7 +78,7 @@ class BaseAlertsResource(ABC):
             labels=labels,
             page=page or 1,
         )
-        max_pages = response["_meta"]["max_pages"]
+        max_pages = response["num_pages"]
         if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
