@@ -1,22 +1,25 @@
 import asyncio
 from abc import ABC
 from datetime import datetime
-from typing import Any, Dict, List, Optional, Sequence
+from typing import Any, Dict, List, Optional, Sequence, TypedDict
 
 from pydantic import validate_arguments
 
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from .errors import ServerError
-from .retry import retry_policy
+from ..errors import ServerError
+from ..retry import retry_policy
 
 PATH = "/users/{user_uuid}/institutions/{institution_id}/balances"
 
-BalanceRecord = Dict[str, Any]
-BalancesMeta = Dict[str, Any]
-BalancesAccount = Dict[str, Any]
-BalancesResponse = Dict[str, Any]
+Balance = Dict[str, Any]
+
+
+class BalancesResponse(TypedDict):
+    page: int
+    num_pages: int
+    balances: List[Balance]
 
 
 class BaseBalancesResource(ABC):
@@ -54,7 +57,9 @@ class BaseBalancesResource(ABC):
             raise ServerError(response.text)
 
         assert response.status_code == 200, response.text
-        return response.json()  # type: ignore
+
+        balances_response: BalancesResponse = response.json()
+        return balances_response
 
     @validate_arguments
     @cache
@@ -67,7 +72,7 @@ class BaseBalancesResource(ABC):
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
         page: Optional[int] = None,
-    ) -> List[BalanceRecord]:
+    ) -> List[Balance]:
         response = await self._get_page(
             user_uuid=user_uuid,
             institution_id=institution_id,
@@ -77,7 +82,7 @@ class BaseBalancesResource(ABC):
             account_types=account_types,
             page=page or 1,
         )
-        max_pages = response["_meta"]["max_pages"]
+        max_pages = response["num_pages"]
         if not page and max_pages > 1:
             coroutines = [
                 self._get_page(
@@ -97,10 +102,9 @@ class BaseBalancesResource(ABC):
             responses = (response,)
 
         return [
-            record
+            balance_record
             for response in responses
-            for balance_account in response["balances"]
-            for record in balance_account["records"]
+            for balance_record in response["balances"]
         ]
 
 
@@ -115,7 +119,7 @@ class AsyncBalancesResource(BaseBalancesResource):
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
         page: Optional[int] = None,
-    ) -> List[BalanceRecord]:
+    ) -> List[Balance]:
         return await self._get(
             user_uuid=user_uuid,
             institution_id=institution_id,
@@ -138,7 +142,7 @@ class SyncBalancesResource(BaseBalancesResource):
         labels: Optional[Sequence[str]] = None,
         account_types: Optional[Sequence[str]] = None,
         page: Optional[int] = None,
-    ) -> List[BalanceRecord]:
+    ) -> List[Balance]:
         return self._client.run(
             self._get(
                 user_uuid=user_uuid,
