@@ -8,10 +8,11 @@ from pydantic import validate_arguments
 from ..cache import cache
 from ..core import BaseClient
 from ..encoders import encode_query_params
-from ..errors import ServerError
+from ..errors import ServerError, UserNotFoundError
 from ..retry import retry_policy
 
 PATH = "/users"
+USER_PATH = "/users/{user_uuid}"
 
 User = Dict[str, Any]
 
@@ -88,6 +89,32 @@ class BaseUsersResource(ABC):
 
         return [user for response in responses for user in response["users"]]
 
+    @retry_policy(
+        max_retry_count=4,
+        max_retry_interval_seconds=10,
+        retryable_exceptions=[ServerError],
+    )
+    @validate_arguments
+    @cache
+    async def _get_user(
+        self,
+        user_uuid: str,
+    ) -> List[User]:
+        async with self._client.session() as session:
+            response = await session.get(
+                USER_PATH.format(user_uuid=user_uuid),
+            )
+
+        if response.status_code == 500:
+            raise ServerError(response.text)
+        if response.status_code == 404:
+            raise UserNotFoundError(response.text)
+
+        assert response.status_code == 200, response.text
+
+        user: User = response.json()
+        return [user]
+
 
 class AsyncUsersResource(BaseUsersResource):
     async def get(
@@ -96,7 +123,12 @@ class AsyncUsersResource(BaseUsersResource):
         created_after: Optional[datetime] = None,
         created_before: Optional[datetime] = None,
         search: Optional[str] = None,
+        user_uuid: Optional[str] = None,
     ) -> List[User]:
+        if user_uuid:
+            return await self._get_user(
+                user_uuid=user_uuid,
+            )
         return await self._get(
             created_after=created_after,
             created_before=created_before,
@@ -111,7 +143,15 @@ class SyncUsersResource(BaseUsersResource):
         created_after: Optional[datetime] = None,
         created_before: Optional[datetime] = None,
         search: Optional[str] = None,
+        user_uuid: Optional[str] = None,
     ) -> List[User]:
+        if user_uuid:
+            return self._client.run(
+                self._get_user(
+                    user_uuid=user_uuid,
+                )
+            )
+
         return self._client.run(
             self._get(
                 created_after=created_after,
